package com.rcpquickstart.videoplayer;

import java.net.URI;
import java.net.URISyntaxException;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;

/**
 * This is a very rudimentary video player that utilizes the VideoControl class.
 * Just trying to test things out.
 * 
 * @author Patrick Paulin
 * 
 */
public class VideoPlayer {
	private Composite parent;
	private VideoControl video;
	private Button playButton;
	private Button openButton;

	public VideoPlayer(Composite parent) {
		this.parent = parent;
		Composite playerComposite = new Composite(parent, SWT.NONE);
		playerComposite.setLayout(new GridLayout(1, false));

		Composite videoComposite = new Composite(playerComposite, SWT.NONE);
		videoComposite.setLayout(new FillLayout());
		videoComposite.setLayoutData(new GridData(GridData.FILL_BOTH));
		this.video = new VideoControl(videoComposite);

		Composite buttonComposite = new Composite(playerComposite, SWT.NONE);
		buttonComposite.setLayout(new RowLayout());

		this.openButton = new Button(buttonComposite, SWT.PUSH);
		openButton.setText("Open");
		openButton.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				video.stop();
				URI uri = getVideoUri();
				if (uri != null) {
					video.setSource(uri);
				}
				updateButtons();
			}
		});

		this.playButton = new Button(buttonComposite, SWT.PUSH);
		playButton.setText("Play");
		playButton.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				if (video.isPlaying()) {
					video.pause();
				} else {
					video.play();
				}
				updateButtons();
			}
		});

		RowData buttonData = new RowData();
		buttonData.width = 100;

		openButton.setLayoutData(buttonData);
		playButton.setLayoutData(buttonData);
	}

	protected URI getVideoUri() {
		InputDialog dialog = new InputDialog(parent.getShell(), "Video URI",
				"Enter a valid URI for the video file you wish to play.", "",
				new IInputValidator() {

					@Override
					public String isValid(String newText) {
						try {
							new URI(newText);
						} catch (Exception e) {
							return "Invalid URI";
						}
						return null;
					}

				});
		if (dialog.open() == Dialog.OK) {
			;
			try {
				return new URI(dialog.getValue());
			} catch (URISyntaxException e) {
				e.printStackTrace();
			}
		}
		return null;
	}

	protected void updateButtons() {
		if (this.video.isPlaying()) {
			this.playButton.setText("Pause");
		} else {
			this.playButton.setText("Play");
		}
	}
}
